FAQ — Django Grappelli v1.3 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli v1.3 documentation »

# FAQ

Some questions, some answers.

## Why should I use Grappelli?

If you are pleased with how the original Admin-Interface looks, you shouldn’t.

## What is it Grappelli does, exactly?

Grappelli replaces the media-files and templates that come with `django.contrib.admin`.

## I need help!

see Troubleshooting.

## Which Browser do I need with Grappelli?

We are testing with Firefox, Chrome and Safari. IE8+ should work as well (but we rarely do any testing with IE).

## Why is there no mercurial– or git–repository?

We have discussed this issue on the Grappelli Google-Group. Since the outcome has been ambiguous, we stay with svn for now.

## Can I use another editor than TinyMCE?

Of course.

## Why don’t you support Admin-Tools?

Django Admin Tools is an awesome app, but it’s just too much effort for us.

## Do you guys cooperate with the Django–Devs?

Occasionally, we discuss features and implementations.

## How can I contribute?

Help is very much needed and appreciated.

- Test Grappelli and submit feedback/patches.
- Take a look at Django Issues.
- Take a look at Django Tickets related to django.contrib.admin.

## What is your goal with Grappelli?

Our goal is that Grappelli will be redundant eventually.

## Who develops Grappelli?

Grappelli is developed and maintained by Patrick Kranzlmüller & Axel Swoboda of vonautomatisch.

### Navigation

- index
- next |
- previous |
- Django Grappelli v1.3 documentation »